wq.app
======

**wq.app/js** are a collection of Javascript modules for building
robust, offline-cabable HTML5 mobile and desktop data collection apps.
Powered by RequireJS, jQuery Mobile, Mustache.js, and `a number of other
awesome libraries <https://github.com/wq/wq.app/tree/master/js/lib>`__.
Great for use with `wq.db <https://github.com/wq/wq.db>`__ or any REST
service.

**wq.app/css** includes the default stylesheets packaged with jQuery
Mobile and Leaflet. **wq.app/scss** provides a SASS/SCSS stylesheet for
use with Compass, with appropriate macros for generating custom jQuery
Mobile themes.

**wq.app/util** provides a Python-based build process for compiling wq
apps: inlining templates, optimizing code (via r.js), and generating an
application cache manifest.
